Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1901)

Unified Diff: src/isolate.h

Issue 10872084: Allocate block-scoped global bindings to global context. (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/heap.cc ('k') | src/isolate.cc » ('j') | src/objects.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/isolate.h
diff --git a/src/isolate.h b/src/isolate.h
index f6544597f25dae4714af2a6c53e3fac891965245..3d0a9c0e0d6509ef07adda523ed7f8e6402ba716 100644
--- a/src/isolate.h
+++ b/src/isolate.h
@@ -764,8 +764,9 @@ class Isolate {
void IterateThread(ThreadVisitor* v, char* t);
// Returns the current native context.
Handle<Context> native_context();
+ Handle<Context> global_context();
// Returns the native context of the calling JavaScript code. That
// is, the native context of the top-most JavaScript frame.
« no previous file with comments | « src/heap.cc ('k') | src/isolate.cc » ('j') | src/objects.cc » ('J')
@@ -764,8 +764,9 @@ class Isolate {
void IterateThread(ThreadVisitor* v, char* t);
- // Returns the current native context.
+ // Returns the current native and global context.
Handle<Context> native_context();

Powered by Google App Engine
This is Rietveld 408576698